@@ -55,6 +55,7 @@ class EC2Instance(VMInterface):
         instance_tags: None,
         volume_tags: None,
         use_private_ip: False,
+        enable_detailed_monitoring=None,
         **kwargs,
     ):
         super().__init__(*args, **kwargs)
@@ -79,6 +80,7 @@ class EC2Instance(VMInterface):
         self.instance_tags = instance_tags
         self.volume_tags = volume_tags
         self.use_private_ip = use_private_ip
+        self.enable_detailed_monitoring = enable_detailed_monitoring
 
     async def create_vm(self):
         """
@@ -112,7 +114,7 @@ class EC2Instance(VMInterface):
                         "Ebs": {
                             "DeleteOnTermination": True,
                             "VolumeSize": self.filesystem_size,
-                            "VolumeType": "gp2",
+                            "VolumeType": "gp3",
                             "Encrypted": False,
                         },
                     }
@@ -121,7 +123,7 @@ class EC2Instance(VMInterface):
                 "InstanceType": self.instance_type,
                 "MaxCount": 1,
                 "MinCount": 1,
-                "Monitoring": {"Enabled": False},
+                "Monitoring": {"Enabled": self.enable_detailed_monitoring},
                 "UserData": self.cluster.render_process_cloud_init(self),
                 "InstanceInitiatedShutdownBehavior": "terminate",
                 "NetworkInterfaces": [
@@ -276,7 +278,20 @@ class EC2Cluster(VMCluster):
         If the instance_type is a GPU instance the NVIDIA drivers and Docker GPU runtime will be installed
         at runtime.
     instance_type: string (optional)
-        A valid EC2 instance type. This will determine the resources available to your workers.
+        A valid EC2 instance type. This will determine the resources available to the scheduler and all workers.
+        If supplied, you may not specify ``scheduler_instance_type`` or ``worker_instance_type``.
+
+        See https://aws.amazon.com/ec2/instance-types/.
+
+        By default will use ``t2.micro``.
+    scheduler_instance_type: string (optional)
+        A valid EC2 instance type.  This will determine the resources available to the scheduler.
+
+        See https://aws.amazon.com/ec2/instance-types/.
+
+        By default will use ``t2.micro``.
+    worker_instance_type: string (optional)
+        A valid EC2 instance type.  This will determine the resources available to all workers.
 
         See https://aws.amazon.com/ec2/instance-types/.
 
@@ -356,6 +371,10 @@ class EC2Cluster(VMCluster):
         Whether to use a private IP (if True) or public IP (if False).
 
         Default ``False``.
+    enable_detailed_monitoring: bool (optional)
+        Whether to enable detailed monitoring for created instances.
+        See https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch-new.html
+        Default ``False``.
 
     Notes
     -----
@@ -453,6 +472,8 @@ class EC2Cluster(VMCluster):
         auto_shutdown=None,
         ami=None,
         instance_type=None,
+        scheduler_instance_type=None,
+        worker_instance_type=None,
         vpc=None,
         subnet_id=None,
         security_groups=None,
@@ -463,7 +484,8 @@ class EC2Cluster(VMCluster):
         debug=False,
         instance_tags=None,
         volume_tags=None,
-        use_private_ip=False,
+        use_private_ip=None,
+        enable_detailed_monitoring=None,
         **kwargs,
     ):
         self.boto_session = get_session()
@@ -490,6 +512,25 @@ class EC2Cluster(VMCluster):
             if instance_type is not None
             else self.config.get("instance_type")
         )
+        if instance_type is None:
+            self.scheduler_instance_type = (
+                scheduler_instance_type
+                if scheduler_instance_type is not None
+                else self.config.get("scheduler_instance_type")
+            )
+            self.worker_instance_type = (
+                worker_instance_type
+                if worker_instance_type is not None
+                else self.config.get("worker_instance_type")
+            )
+        else:
+            if scheduler_instance_type is not None or worker_instance_type is not None:
+                raise ValueError(
+                    "If you specify instance_type, you may not specify scheduler_instance_type or worker_instance_type"
+                )
+            self.scheduler_instance_type = instance_type
+            self.worker_instance_type = instance_type
+
         self.gpu_instance = self.instance_type.startswith(("p", "g"))
         self.vpc = vpc if vpc is not None else self.config.get("vpc")
         self.subnet_id = (
@@ -522,7 +563,17 @@ class EC2Cluster(VMCluster):
         volume_tags = volume_tags if volume_tags is not None else {}
         self.volume_tags = {**volume_tags, **self.config.get("volume_tags")}
 
-        self._use_private_ip = use_private_ip
+        self._use_private_ip = (
+            use_private_ip
+            if use_private_ip is not None
+            else self.config.get("use_private_ip")
+        )
+
+        self.enable_detailed_monitoring = (
+            enable_detailed_monitoring
+            if enable_detailed_monitoring is not None
+            else self.config.get("enable_detailed_monitoring")
+        )
 
         self.options = {
             "cluster": self,
@@ -533,6 +584,8 @@ class EC2Cluster(VMCluster):
             "ami": self.ami,
             "docker_image": docker_image or self.config.get("docker_image"),
             "instance_type": self.instance_type,
+            "scheduler_instance_type": self.scheduler_instance_type,
+            "worker_instance_type": self.worker_instance_type,
             "gpu_instance": self.gpu_instance,
             "vpc": self.vpc,
             "subnet_id": self.subnet_id,
@@ -543,7 +596,10 @@ class EC2Cluster(VMCluster):
             "instance_tags": self.instance_tags,
             "volume_tags": self.volume_tags,
             "use_private_ip": self._use_private_ip,
+            "enable_detailed_monitoring": self.enable_detailed_monitoring,
         }
         self.scheduler_options = {**self.options}
         self.worker_options = {**self.options}
+        self.scheduler_options["instance_type"] = self.scheduler_instance_type
+        self.worker_options["instance_type"] = self.worker_instance_type
         super().__init__(debug=debug, **kwargs)
