@@ -16,6 +16,7 @@ from dask_cloudprovider.aws.helper import (
     get_default_vpc,
     get_vpc_subnets,
     create_default_security_group,
+    ConfigMixin,
 )
 
 from distributed.deploy.spec import SpecCluster
@@ -66,13 +67,6 @@ class Task:
         The security groups to attach to the ENI that will be created when
         launching this task.
 
-    log_group: str
-        The log group to send all task logs to.
-
-    log_stream_prefix: str
-        A prefix for the log stream that will be created automatically in the
-        log group when launching this task.
-
     fargate: bool
         Whether or not to launch on Fargate.
 
@@ -82,10 +76,6 @@ class Task:
     tags: str
         AWS resource tags to be applied to any resources that are created.
 
-    find_address_timeout: int
-        Configurable timeout in seconds for finding the task IP from the
-        cloudwatch logs.
-
     name: str (optional)
         Name for the task. Currently used for the --namecommand line argument to dask-worker.
 
@@ -122,24 +112,19 @@ class Task:
         task_definition_arn,
         vpc_subnets,
         security_groups,
-        log_group,
-        log_stream_prefix,
         fargate,
         environment,
         tags,
-        find_address_timeout,
         name=None,
         platform_version=None,
         fargate_use_private_ip=False,
         fargate_capacity_provider=None,
         task_kwargs=None,
-        **kwargs
+        **kwargs,
     ):
         self.lock = asyncio.Lock()
         self._client = client
         self.name = name
-        self.address = None
-        self.external_address = None
         self.cluster_arn = cluster_arn
         self.task_definition_arn = task_definition_arn
         self.task = None
@@ -147,8 +132,6 @@ class Task:
         self.task_type = None
         self.public_ip = None
         self.private_ip = None
-        self.log_group = log_group
-        self.log_stream_prefix = log_stream_prefix
         self.connection = None
         self._overrides = {}
         self._vpc_subnets = vpc_subnets
@@ -156,7 +139,6 @@ class Task:
         self.fargate = fargate
         self.environment = environment or {}
         self.tags = tags
-        self._find_address_timeout = find_address_timeout
         self.platform_version = platform_version
         self._fargate_use_private_ip = fargate_use_private_ip
         self._fargate_capacity_provider = fargate_capacity_provider
@@ -206,31 +188,6 @@ class Task:
                     break
                 await asyncio.sleep(wait_duration)
 
-    async def _set_address_from_logs(self):
-        timeout = Timeout(
-            self._find_address_timeout,
-            "Failed to find {} ip address after {} seconds.".format(
-                self.task_type, self._find_address_timeout
-            ),
-        )
-        while timeout.run():
-            async for line in self.logs():
-                for query_string in ["worker at:", "Scheduler at:"]:
-                    if query_string in line:
-                        address = line.split(query_string)[1].strip()
-                        if self._use_public_ip:
-                            self.external_address = address.replace(
-                                self.private_ip, self.public_ip
-                            )
-                        logger.debug("%s", line)
-                        self.address = address
-                        return
-            else:
-                if not await self._task_is_running():
-                    raise RuntimeError("%s exited unexpectedly!" % type(self).__name__)
-                continue
-            break
-
     async def _task_is_running(self):
         await self._update_task()
         return self.task["lastStatus"] == "RUNNING"
@@ -322,7 +279,6 @@ class Task:
         if self._use_public_ip:
             self.public_ip = interface["Association"]["PublicIp"]
         self.private_ip = interface["PrivateIpAddresses"][0]["PrivateIpAddress"]
-        await self._set_address_from_logs()
         self.status = Status.running
 
     async def close(self, **kwargs):
@@ -397,13 +353,47 @@ class Task:
 
 class Scheduler(Task):
     """A Remote Dask Scheduler controlled by ECS
+    Parameters
+    ----------
+    port: int
+        The external port on which the scheduler will be listening.
+        Note: If the task is launched with a default configuration, the internal and
+        external port will be the same. Otherwise it is the caller's responsibility to
+        set up the task such that the scheduler is reachable on this port.
+    scheduler_timeout: str
+        Time of inactivity after which to kill the scheduler.
+    scheduler_extra_args: List[str] (optional)
+        Any extra command line arguments to pass to dask-scheduler, e.g. ``["--tls-cert", "/path/to/cert.pem"]``
+
+        Defaults to `None`, no extra command line arguments.
+    kwargs: Dict()
+        Other kwargs to be passed to :class:`Task`.
 
     See :class:`Task` for parameter info.
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, port, scheduler_timeout, scheduler_extra_args=None, **kwargs):
         super().__init__(**kwargs)
+        self.port = port
         self.task_type = "scheduler"
+        self._overrides = {
+            "command": [
+                "dask-scheduler",
+                "--idle-timeout",
+                scheduler_timeout,
+            ]
+            + (list() if not scheduler_extra_args else scheduler_extra_args)
+        }
+
+    @property
+    def address(self):
+        ip = getattr(self, "private_ip", None)
+        return f"{ip}:{self.port}" if ip else None
+
+    @property
+    def external_address(self):
+        ip = getattr(self, "public_ip", None)
+        return f"{ip}:{self.port}" if ip else None
 
 
 class Worker(Task):
@@ -425,7 +415,7 @@ class Worker(Task):
         gpu: int,
         nthreads: Optional[int],
         extra_args: List[str],
-        **kwargs
+        **kwargs,
     ):
         super().__init__(**kwargs)
         self.task_type = "worker"
@@ -455,7 +445,7 @@ class Worker(Task):
         }
 
 
-class ECSCluster(SpecCluster):
+class ECSCluster(SpecCluster, ConfigMixin):
     """Deploy a Dask cluster using ECS
 
     This creates a dask scheduler and workers on an existing ECS cluster.
@@ -498,10 +488,21 @@ class ECSCluster(SpecCluster):
         The scheduler task will exit after this amount of time if there are no clients connected.
 
         Defaults to ``5 minutes``.
+    scheduler_port: int (optional)
+        The port on which the scheduler should listen.
+
+        Defaults to ``8786``
     scheduler_extra_args: List[str] (optional)
         Any extra command line arguments to pass to dask-scheduler, e.g. ``["--tls-cert", "/path/to/cert.pem"]``
 
         Defaults to `None`, no extra command line arguments.
+    scheduler_task_definition_arn: str (optional)
+        The arn of the task definition that the cluster should use to start the scheduler task. If provided, this will
+        override the `image`, `scheduler_cpu`, `scheduler_mem`, any role settings, any networking / VPC settings, as
+        these are all part of the task definition.
+
+        Defaults to `None`, meaning that the task definition will be created along with the cluster, and cleaned up once
+        the cluster is shut down.
     scheduler_task_kwargs: dict (optional)
         Additional keyword arguments for the scheduler ECS task.
     scheduler_address: str (optional)
@@ -530,7 +531,13 @@ class ECSCluster(SpecCluster):
         cluster. Fargate is not supported at this time.
 
         Defaults to `None`, no GPUs.
+    worker_task_definition_arn: str (optional)
+        The arn of the task definition that the cluster should use to start the worker tasks. If provided, this will
+        override the `image`, `worker_cpu`, `worker_mem`, any role settings, any networking / VPC settings, as
+        these are all part of the task definition.
 
+        Defaults to `None`, meaning that the task definition will be created along with the cluster, and cleaned up once
+        the cluster is shut down.
     worker_extra_args: List[str] (optional)
         Any extra command line arguments to pass to dask-worker, e.g. ``["--tls-cert", "/path/to/cert.pem"]``
 
@@ -633,11 +640,6 @@ class ECSCluster(SpecCluster):
         Tags to apply to all resources created automatically.
 
         Defaults to ``None``. Tags will always include ``{"createdBy": "dask-cloudprovider"}``
-    find_address_timeout: int
-        Configurable timeout in seconds for finding the task IP from the
-        cloudwatch logs.
-
-        Defaults to 60 seconds.
     skip_cleanup: bool (optional)
         Skip cleaning up of stale resources. Useful if you have lots of resources
         and this operation takes a while.
@@ -696,14 +698,16 @@ class ECSCluster(SpecCluster):
 
     def __init__(
         self,
-        fargate_scheduler=False,
-        fargate_workers=False,
-        fargate_spot=False,
+        fargate_scheduler=None,
+        fargate_workers=None,
+        fargate_spot=None,
         image=None,
         scheduler_cpu=None,
         scheduler_mem=None,
+        scheduler_port=8786,
         scheduler_timeout=None,
         scheduler_extra_args=None,
+        scheduler_task_definition_arn=None,
         scheduler_task_kwargs=None,
         scheduler_address=None,
         worker_cpu=None,
@@ -711,6 +715,7 @@ class ECSCluster(SpecCluster):
         worker_mem=None,
         worker_gpu=None,
         worker_extra_args=None,
+        worker_task_definition_arn=None,
         worker_task_kwargs=None,
         n_workers=None,
         workers_name_start=0,
@@ -728,7 +733,6 @@ class ECSCluster(SpecCluster):
         security_groups=None,
         environment=None,
         tags=None,
-        find_address_timeout=None,
         skip_cleanup=None,
         aws_access_key_id=None,
         aws_secret_access_key=None,
@@ -738,7 +742,7 @@ class ECSCluster(SpecCluster):
         mount_points=None,
         volumes=None,
         mount_volumes_on_scheduler=False,
-        **kwargs
+        **kwargs,
     ):
         self._fargate_scheduler = fargate_scheduler
         self._fargate_workers = fargate_workers
@@ -746,14 +750,23 @@ class ECSCluster(SpecCluster):
         self.image = image
         self._scheduler_cpu = scheduler_cpu
         self._scheduler_mem = scheduler_mem
+        self._scheduler_port = scheduler_port
         self._scheduler_timeout = scheduler_timeout
         self._scheduler_extra_args = scheduler_extra_args
+        self.scheduler_task_definition_arn = scheduler_task_definition_arn
+        self._scheduler_task_definition_arn_provided = (
+            scheduler_task_definition_arn is not None
+        )
         self._scheduler_task_kwargs = scheduler_task_kwargs
         self._scheduler_address = scheduler_address
         self._worker_cpu = worker_cpu
         self._worker_nthreads = worker_nthreads
         self._worker_mem = worker_mem
         self._worker_gpu = worker_gpu
+        self.worker_task_definition_arn = worker_task_definition_arn
+        self._worker_task_definition_arn_provided = (
+            worker_task_definition_arn is not None
+        )
         self._worker_extra_args = worker_extra_args
         self._worker_task_kwargs = worker_task_kwargs
         self._n_workers = n_workers
@@ -773,7 +786,6 @@ class ECSCluster(SpecCluster):
         self._security_groups = security_groups
         self._environment = environment
         self._tags = tags
-        self._find_address_timeout = find_address_timeout
         self._skip_cleanup = skip_cleanup
         self._fargate_use_private_ip = fargate_use_private_ip
         self._mount_points = mount_points
@@ -807,18 +819,37 @@ class ECSCluster(SpecCluster):
 
         self.config = dask.config.get("cloudprovider.ecs", {})
 
-        if self._region_name is None:
-            self._region_name = self.config.get("region_name")
+        for attr in [
+            "aws_access_key_id",
+            "aws_secret_access_key",
+            "cloudwatch_logs_default_retention",
+            "cluster_name_template",
+            "environment",
+            "fargate_scheduler",
+            "fargate_spot",
+            "fargate_workers",
+            "fargate_use_private_ip",
+            "n_workers",
+            "platform_version",
+            "region_name",
+            "scheduler_cpu",
+            "scheduler_mem",
+            "scheduler_port",
+            "scheduler_timeout",
+            "skip_cleanup",
+            "tags",
+            "task_role_policies",
+            "worker_cpu",
+            "worker_gpu",  # TODO Detect whether cluster is GPU capable
+            "worker_mem",
+            "worker_nthreads",
+            "vpc",
+        ]:
+            self.update_attr_from_config(attr=attr, private=True)
 
-        if self._aws_access_key_id is None:
-            self._aws_access_key_id = self.config.get("aws_access_key_id")
-
-        if self._aws_secret_access_key is None:
-            self._aws_secret_access_key = self.config.get("aws_secret_access_key")
+        self._check_scheduler_port_config()
 
         # Cleanup any stale resources before we start
-        if self._skip_cleanup is None:
-            self._skip_cleanup = self.config.get("skip_cleanup")
         if not self._skip_cleanup:
             await _cleanup_stale_resources(
                 aws_access_key_id=self._aws_access_key_id,
@@ -826,72 +857,24 @@ class ECSCluster(SpecCluster):
                 region_name=self._region_name,
             )
 
-        if self._fargate_scheduler is None:
-            self._fargate_scheduler = self.config.get("fargate_scheduler")
-        if self._fargate_workers is None:
-            self._fargate_workers = self.config.get("fargate_workers")
-        if self._fargate_spot is None:
-            self._fargate_spot = self.config.get("fargate_spot")
-
-        if self._tags is None:
-            self._tags = self.config.get("tags")
-
-        if self._environment is None:
-            self._environment = self.config.get("environment")
-
-        if self._find_address_timeout is None:
-            self._find_address_timeout = self.config.get("find_address_timeout", 60)
-
-        if self._worker_gpu is None:
-            self._worker_gpu = self.config.get(
-                "worker_gpu"
-            )  # TODO Detect whether cluster is GPU capable
-
         if self.image is None:
             if self._worker_gpu:
                 self.image = self.config.get("gpu_image")
             else:
                 self.image = self.config.get("image")
 
-        if self._scheduler_cpu is None:
-            self._scheduler_cpu = self.config.get("scheduler_cpu")
-
-        if self._scheduler_mem is None:
-            self._scheduler_mem = self.config.get("scheduler_mem")
-
-        if self._scheduler_timeout is None:
-            self._scheduler_timeout = self.config.get("scheduler_timeout")
-
         if self._scheduler_extra_args is None:
             comma_separated_args = self.config.get("scheduler_extra_args")
             self._scheduler_extra_args = (
                 comma_separated_args.split(",") if comma_separated_args else None
             )
 
-        if self._worker_cpu is None:
-            self._worker_cpu = self.config.get("worker_cpu")
-
-        if self._worker_nthreads is None:
-            self._worker_nthreads = self.config.get("worker_nthreads")
-
-        if self._worker_mem is None:
-            self._worker_mem = self.config.get("worker_mem")
-
         if self._worker_extra_args is None:
             comma_separated_args = self.config.get("worker_extra_args")
             self._worker_extra_args = (
                 comma_separated_args.split(",") if comma_separated_args else None
             )
 
-        if self._n_workers is None:
-            self._n_workers = self.config.get("n_workers")
-
-        if self._cluster_name_template is None:
-            self._cluster_name_template = self.config.get("cluster_name_template")
-
-        if self._platform_version is None:
-            self._platform_version = self.config.get("platform_version")
-
         if self.cluster_arn is None:
             self.cluster_arn = (
                 self.config.get("cluster_arn") or await self._create_cluster()
@@ -910,9 +893,6 @@ class ECSCluster(SpecCluster):
                 or await self._create_execution_role()
             )
 
-        if self._task_role_policies is None:
-            self._task_role_policies = self.config.get("task_role_policies")
-
         if self._task_role_arn is None:
             self._task_role_arn = (
                 self.config.get("task_role_arn") or await self._create_task_role()
@@ -923,20 +903,12 @@ class ECSCluster(SpecCluster):
                 "cloudwatch_logs_stream_prefix"
             ).format(cluster_name=self.cluster_name)
 
-        if self._cloudwatch_logs_default_retention is None:
-            self._cloudwatch_logs_default_retention = self.config.get(
-                "cloudwatch_logs_default_retention"
-            )
-
         if self.cloudwatch_logs_group is None:
             self.cloudwatch_logs_group = (
                 self.config.get("cloudwatch_logs_group")
                 or await self._create_cloudwatch_logs_group()
             )
 
-        if self._vpc is None:
-            self._vpc = self.config.get("vpc")
-
         if self._vpc == "default":
             async with self._client("ec2") as client:
                 self._vpc = await get_default_vpc(client)
@@ -953,12 +925,14 @@ class ECSCluster(SpecCluster):
                 or await self._create_security_groups()
             )
 
-        self.scheduler_task_definition_arn = (
-            await self._create_scheduler_task_definition_arn()
-        )
-        self.worker_task_definition_arn = (
-            await self._create_worker_task_definition_arn()
-        )
+        if self.scheduler_task_definition_arn is None:
+            self.scheduler_task_definition_arn = (
+                await self._create_scheduler_task_definition_arn()
+            )
+        if self.worker_task_definition_arn is None:
+            self.worker_task_definition_arn = (
+                await self._create_worker_task_definition_arn()
+            )
 
         options = {
             "client": self._client,
@@ -969,7 +943,6 @@ class ECSCluster(SpecCluster):
             "log_stream_prefix": self._cloudwatch_logs_stream_prefix,
             "environment": self._environment,
             "tags": self.tags,
-            "find_address_timeout": self._find_address_timeout,
             "platform_version": self._platform_version,
             "fargate_use_private_ip": self._fargate_use_private_ip,
         }
@@ -977,7 +950,10 @@ class ECSCluster(SpecCluster):
             "task_definition_arn": self.scheduler_task_definition_arn,
             "fargate": self._fargate_scheduler,
             "fargate_capacity_provider": "FARGATE" if self._fargate_spot else None,
+            "port": self._scheduler_port,
             "task_kwargs": self._scheduler_task_kwargs,
+            "scheduler_timeout": self._scheduler_timeout,
+            "scheduler_extra_args": self._scheduler_extra_args,
             **options,
         }
         worker_options = {
@@ -1243,10 +1219,11 @@ class ECSCluster(SpecCluster):
         return response["taskDefinition"]["taskDefinitionArn"]
 
     async def _delete_scheduler_task_definition_arn(self):
-        async with self._client("ecs") as ecs:
-            await ecs.deregister_task_definition(
-                taskDefinition=self.scheduler_task_definition_arn
-            )
+        if not self._scheduler_task_definition_arn_provided:
+            async with self._client("ecs") as ecs:
+                await ecs.deregister_task_definition(
+                    taskDefinition=self.scheduler_task_definition_arn
+                )
 
     async def _create_worker_task_definition_arn(self):
         resource_requirements = []
@@ -1316,10 +1293,11 @@ class ECSCluster(SpecCluster):
         return response["taskDefinition"]["taskDefinitionArn"]
 
     async def _delete_worker_task_definition_arn(self):
-        async with self._client("ecs") as ecs:
-            await ecs.deregister_task_definition(
-                taskDefinition=self.worker_task_definition_arn
-            )
+        if not self._worker_task_definition_arn_provided:
+            async with self._client("ecs") as ecs:
+                await ecs.deregister_task_definition(
+                    taskDefinition=self.worker_task_definition_arn
+                )
 
     def logs(self):
         async def get_logs(task):
@@ -1339,6 +1317,33 @@ class ECSCluster(SpecCluster):
         }
         return Logs({**scheduler_logs, **worker_logs})
 
+    def _check_scheduler_port_config(self):
+        port_value = None
+        if "--port" in (self._scheduler_extra_args or []):
+            port_param_index = self._scheduler_extra_args.index("--port")
+            port_value_index = port_param_index + 1
+            if port_value_index < len(self._scheduler_extra_args):
+                port_value = int(self._scheduler_extra_args[+1])
+        if port_value:
+            if port_value != self._scheduler_port:
+                warnings.warn(
+                    f"--port provided in scheduler_extra_args ({port_value}) did not "
+                    "match port provided in cluster configuration "
+                    f"({self._scheduler_port}). This can be OK if the task has port "
+                    "mappings to map the scheduler's internal port to this external "
+                    "port value. If the cluster fails to connect to the scheduler, try "
+                    "setting these to the same value."
+                )
+        elif self._scheduler_port != 8786:
+            warnings.warn(
+                f"non-default scheduler port ({self._scheduler_port}) was "
+                "specified, but no port override was found in "
+                "scheduler_extra_args. This can be OK if the port is overridden in "
+                "the scheduler configuration elsewhere, or if there is a port "
+                "mapping in the task to map the scheduler port to the specified "
+                "port."
+            )
+
 
 class FargateCluster(ECSCluster):
     """Deploy a Dask cluster using Fargate on ECS
